pub struct SubscriptionFailurePolicy {
pub max_redelivery_count: u32,
pub ack_timeout_ms: u64,
pub base_redelivery_delay_ms: u64,
pub max_redelivery_delay_ms: u64,
pub backoff_strategy: i32,
pub dead_letter_topic: Option<String>,
pub poison_policy: i32,
}Fields
max_redelivery_count: u32ack_timeout_ms: u64base_redelivery_delay_ms: u64max_redelivery_delay_ms: u64backoff_strategy: i32dead_letter_topic: Option<String>poison_policy: i32Implementations
Sourceimpl SubscriptionFailurePolicy
impl SubscriptionFailurePolicy
Sourcepub fn backoff_strategy(&self) -> SubscriptionBackoffStrategy
pub fn backoff_strategy(&self) -> SubscriptionBackoffStrategy
Returns the enum value of backoff_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_backoff_strategy(&mut self, value: SubscriptionBackoffStrategy)
pub fn set_backoff_strategy(&mut self, value: SubscriptionBackoffStrategy)
Sets backoff_strategy to the provided enum value.
Sourcepub fn dead_letter_topic(&self) -> &str
pub fn dead_letter_topic(&self) -> &str
Returns the value of dead_letter_topic, or the default value if dead_letter_topic is unset.
Sourcepub fn poison_policy(&self) -> SubscriptionPoisonPolicy
pub fn poison_policy(&self) -> SubscriptionPoisonPolicy
Returns the enum value of poison_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_poison_policy(&mut self, value: SubscriptionPoisonPolicy)
pub fn set_poison_policy(&mut self, value: SubscriptionPoisonPolicy)
Sets poison_policy to the provided enum value.