NackRequest

Struct NackRequest 

pub struct NackRequest {
    pub request_id: u64,
    pub msg_id: Option<MsgId>,
    pub subscription_name: String,
    pub delay_ms: Option<u64>,
    pub reason: Option<String>,
}

Fields

request_id: u64msg_id: Option<MsgId>

Identifies the message, associated with a unique topic, subscription and the broker

subscription_name: String

Subscription name the consumer is subscribed to

delay_ms: Option<u64>reason: Option<String>

Implementations

Source

impl NackRequest

pub fn delay_ms(&self) -> u64

Returns the value of delay_ms, or the default value if delay_ms is unset.

pub fn reason(&self) -> &str

Returns the value of reason, or the default value if reason is unset.